pub fn apply_diff(state: &mut TableState, d: &TableStateDiff)Expand description
Apply a TableStateDiff to a TableState, mutating it in place.
Fields that are None in the diff are left unchanged.
pub fn apply_diff(state: &mut TableState, d: &TableStateDiff)Apply a TableStateDiff to a TableState, mutating it in place.
Fields that are None in the diff are left unchanged.