pub fn diff(old: &TableState, new: &TableState) -> TableStateDiffExpand description
Compute the diff from old to new.
Only fields that differ are set in the returned TableStateDiff.
pub fn diff(old: &TableState, new: &TableState) -> TableStateDiffCompute the diff from old to new.
Only fields that differ are set in the returned TableStateDiff.